===================================================
Tonarchiv des CNRS - Musée de l'Homme
===================================================

Der Aufbau des Tonarchives des Zentrums für musikethnologische Forschung, `CREM <http://www.crem-cnrs.fr>`_, ist der Erfolg einer langen Geschichte der wissenschaftlichen Erforschung der Musik. Seit der Entstehung der Ethnomusikologie (also der "vergleichenden Musikologie"), die zusammenfällt mit der Erfindung der ersten Tonaufzeichnungsgeräte am Ende des 19. Jahrhunderts, besitzen die Aufzeichnung von musikalischen Dokumenten, ebenso wie ihre Klassifikation und ihre Konservierung einen zentralen Platz in unserem Wissen über den musikalischen Menschen.

.. image:: home_img.jpg
    :align: left

Mit der Eröffnung der Phonothek im Ethnographischen Museum am Trocadéro durch André Schaeffner im Jahre 1932 (woraus 1937 die Phonothek des "Musée de l'Homme" wurde) und der Schaffung des "Laboratoriums für Tonanalyse" auf Initiative von Gilbert Rouget, ebenso wie durch die Schaffung einer Forschungsgruppe des `CNRS <http://www.cnrs.fr/>`_ im Jahr 1968, beide im "`Musée de l’Homme <http://www.museedelhomme.fr/>`_", wurde die Konservierung des riesigen Fundus des Tonarchivs enger an die Forschung angebunden: Sie wird gespiesen durch die Expeditionen der Forschenden auf allen Kontinenten; diese Sammlungen dienen zugleich auch der Forschung im Labor, für diachrone und synchrone Vergleiche, für die Entstehung neuer Arbeitsgebiete und zur Ausbildung von Doktorierenden. 1985 beschlossen das `CNRS <http://www.cnrs.fr/>`_ und das `Nationale Naturhistorische Museum <http://www.mnhn.fr/>`_, ihre Anstrengungen zu bündeln, um diesen riesigen Archivbestand zu erhalten. Er bekam den Namen "Tonarchiv CNRS - Musée de l'Homme". Ein kleiner Teil des Archivs wurde publiziert auf 78-Touren-Schallplatten (Africa Vox, etc.), auf 33-Touren-Schallplatten und auf CD (Chant du Monde, Harmonia Mundi). Derzeit werden die analogen Tongträger digitalisiert mit der Unterstützung des Kulturministeriums und der Nationalbibliothek. Mit der Gründung des `Zentrums für musikethnologische Forschung <http://www.crem-cnrs.fr>`_ (CREM, Labor für Ethnologie und vergleichende Soziologie, UMR 7186) an der Universität Paris Ouest - Nanterre La Défense im Jahre 2009 und der Eröffnung der Plattform `Telemeta <http://telemeta.org>`_ im Jahr 2011, finden diese Tonarchivbestände Eingang in das Internetzeitalter.

Die Archive des CREM gehören zu den wichtigsten in Europa. Sie zeichnen sich insbesondere aus durch ihre Reichhaltigkeit:

 * mehr als 3'500 Stunden unpublizierte Aufzeichnungen aus dem Feld
 * rund 3'700 Stunden veröffentlichte Dokumente (mehr als 5'000 Schallplatten, darunter viele sehr seltene)

Die kollaborative Plattform `Telemeta <http://telemeta.org>`_ hat zum Ziel, diese Bestände zugänglich zu machen für Forschende, und soweit möglich auch für die Oeffentlichkeit, unter Respektierung des geistigen und moralischen Eigentums der MusikerInnen und SammlerInnen. Aufgebaut mit der Unterstützung des Programmes `TGE-Adonis <http://www.tge-adonis.fr/>`_ des `CNRS <http://www.cnrs.fr/>`_, erlaubt die Plattform den Forschenden den online-Austausch mit den Gemeinschaften, aus denen die Musik stammt, in ihrem Ursprungsland, insbesondere auch durch kollaborative Werkzeuge wie Zeitmarken, Kommentarfunktionen etc.

Die Verwaltung der Plattform wird durch das `CREM <http://www.crem-cnrs.fr>`_ sichergestellt. Das Internetangebot ist offen für jede Zusammenarbeit, die zum Ziel hat, dieses wertvolle, gemeinsame Erbe der Menschheit zu bereichern und zu würdigen. Derzeit sind 1'000 Stunden online zugänglich. Sie stehen zudem zur Verfügung `vor Ort im CREM (Universität Paris Ouest - Naterre La Défense, Gebäude C, Erdgeschoss, Zimmer 20) <http://goo.gl/maps/ZgHg>`_, sowie in der Zentralbibliothek des Nationalen Naturhistorischen Museums und in der Bibliothek François Mitterand (Gartengeschoss).

